PyXMake Developer Guide: PyXMake.VTL.cmake Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions | Variables
PyXMake.VTL.cmake Namespace Reference

## Functions
| main (BuildID, source=os.path.join(__mcd_core_path,"config"), output=None, scratch=VTL.Scratch, verbosity=2, **kwargs)

## Variables
| foss

## Detailed Description

    Minimum working example for PyXMake.

    @note: Compile a project using CMAKE on windows.
    Created on 15.01.2024

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake

    @change:
          -

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

PyXMake.VTL.cmake.main | ( |  | BuildID,
|  |  | source = os.path.join(__mcd_core_path,"config"),
|  |  | output = None,
|  |  | scratch = VTL.Scratch,
|  |  | verbosity = 2,
|  | ** | kwargs )

    Main function to execute the script.

Definition at line 47 of file cmake.py.

## Variable Documentation

## ◆ foss

PyXMake.VTL.cmake.foss

Definition at line 73 of file cmake.py.